@@ -1,7 +1,7 @@
 package Software::Catalog::SW::firefox;
 
-our $DATE = '2018-09-13'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2018-09-20'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +48,13 @@ sub get_download_url {
     # "https://archive.mozilla.org/pub/firefox/releases/62.0/source/"
 }
 
+sub get_programs {
+    my ($self, %args) = @_;
+    [200, "OK", [
+        {name=>"firefox", path=>"/"},
+    ]];
+}
+
 1;
 # ABSTRACT: Firefox
 
@@ -63,7 +70,7 @@ Software::Catalog::SW::firefox - Firefox
 
 =head1 VERSION
 
-This document describes version 0.001 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2018-09-13.
+This document describes version 0.002 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2018-09-20.
 
 =for Pod::Coverage ^(.+)$
 
